#' @title Titanium concentrations and their locations
#'
#' @description
#' The titanium concentrations were measured in 3,316 samples of stream
#' sediments from
#' the Atlantic Coastal Plain of the southeastern U.S.
#'
#' @format
#' The data are stored in an R-language dataframe. Each row pertains to one
#' sample; there are 3,316 rows.
#' Column \code{labno} contains the laboratory numbers, which serve as
#' unique identifers. Columns \code{long} and \code{lat} contain the longitudes
#' and latitudes of the samples. Column \code{conc} contains the titanium
#' concentrations for which the units are milligrams per kilogram, or
#' equivalently, parts per million.
#'
#' @details
#' The datum for the longitude and latitude is WGS84.
#'
#' These data also are available at Ellefsen (2017). It was found that 141
#' measurements from Ellefsen (2017) were duplicates---for a duplicate,
#' 2 measurements were made at exactly the same location. These duplicates
#' have been removed for the dataset in this package.
#'
#' @references
#' Ellefsen, K.J., 2017, Titanium concentrations in stream sediments from the
#' Atlantic Coastal Plain of the southeastern U.S. (1975–1999): U.S. Geological
#' Survey data release, accessed February 2018 at
#' \url{https://doi.org/10.5066/F7J38R16}
#'
"Example_dataset"

#' @title Boundary of the domain for the example dataset.
#'
#' @description
#' The boundary of the domain is represented by a polygon. Consequently,
#' the boundary is defined by the locations of the polygon vertices.
#'
#' @format
#' The data are stored in an R-language data frame. Each row pertains to one
#' vertex in the polygon. Columns \code{long} and \code{lat} contain the
#' longitudes and latitudes of the vertices.
#'
#' @details
#' The datum for the longitude and latitude is WGS84.
#'
"Example_domain"

#' @title Boundary of the region of interest (roi) for the example dataset.
#'
#' @description
#' The boundary of the roi is represented by a polygon. Consequently, the
#' boundary is defined by the locations of the polygon vertices.
#'
#' @format
#' The data are stored in an R-language data frame. Each row pertains to one
#' vertex in the polygon. Columns \code{long} and \code{lat} contain the
#' longitudes and latitudes of the points.
#'
#' @details
#' The datum for the longitude and latitude is WGS84.
#'
"Example_roi"

#' @title Repeated measurements of titanium concentration in reference sample 1
#'
#' @description
#' This reference sample was used for quality control when the titanium
#' concentrations in the example dataset were measured.
#' The number of repeated measurements is 62.
#'
#' @format
#' The data are stored in an R-language tibble. Each row pertains to one
#' measurement of the reference sample. There are 62 rows in the tibble.
#' Column \code{conc} contains the titanium
#' concentrations for which the units are milligrams per kilogram, or
#' equivalently, parts per million.
#'
"Example_repeat_meas1"

#' @title Repeated measurements of titanium concentration in reference sample 2
#'
#' @description
#' This reference sample was used for quality control when the titanium
#' concentrations in the example dataset were measured.
#' The number of repeated measurements is 63.
#'
#' @format
#' The data are stored in an R-language tibble. Each row pertains to one
#' measurement of the reference sample. There are 63 rows in the tibble.
#' Column \code{conc} contains the titanium
#' concentrations for which the units are milligrams per kilogram, or
#' equivalently, parts per million.
#'
"Example_repeat_meas2"

#' @title Projection information for longitudes and latitudes in the
#' example dataset
#'
#' @description
#' Argument to function sp::CRS that specfies the projection of the locations
#' in the example dataset. This projection pertains to locations specified
#' as longitudes and latitudes.
#'
#' @format
#' The argument is a character string, which is described in the documentation
#' of function sp::CRS.
#'
"Example_CRS_arg_longlat"

#' @title Projection information for unversial transverse mercator coordinates
#' in the example dataset
#'
#' @description
#' Argument to function sp::CRS that specfies the projection of the locations
#' in the example dataset. This projection pertains to locations specified
#' as universal transverse mercator coordinates.
#'
#' @format
#' The argument is a character string, which is described in the documentation
#' of function sp::CRS.
#'
"Example_CRS_arg_utm"

