% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BasisFunctions.R
\name{BasisFunctions}
\alias{BasisFunctions}
\title{Constructor of class to generate basis functions.}
\usage{
BasisFunctions(spacings, domain_boundary, spatialData, CRS_arg_utm,
  directory_name = "BasisFunctions", seed = NULL,
  prune_minFuncValue = 0.1, prune_minNumSamples = 5,
  prune_areOutsideRemoved = FALSE, estNNZ = as.integer(1e+07))
}
\arguments{
\item{spacings}{Vector of character strings. Each element contains the spacing
(in kilometers) between the basis function centers.}

\item{domain_boundary}{Dataframe containing the longitudes and latitudes of the
points that define the boundary of the domain. The first column
of the dataframe lists the longitudes, and the second column
the latitudes. The column names are "long" and "lat".}

\item{spatialData}{Container with the spatial data and associated information.
See the User's Guide for a detailed description of this container.}

\item{CRS_arg_utm}{Character string containing the arguments to function sp::CRS that
specify the projection, in universal transverse mercator (utm) coordinates,
for arguments domain_boundary and spatialData.}

\item{directory_name}{Character string containing the name of the directory that will store
the files with the basis functions.}

\item{seed}{Random number seed.}

\item{prune_minFuncValue}{See details.}

\item{prune_minNumSamples}{See details.}

\item{prune_areOutsideRemoved}{See details.}

\item{estNNZ}{Estimated maximum number of non-zero elements in the matrix that contains the
basis functions.}
}
\value{
A list with the following components is returned.

\item{spacings}{Argument spacings.}

\item{domain_boundary}{Argument domain_boundary.}

\item{estNNZ}{Argument estNNZ.}

\item{file_info}{R-language tibble containing the names of the
files storing the basis functions and the associated spacings between the
function centers.}

\item{call}{Function call.}
}
\description{
This constructor generates a set of basis functions for each
specfied spacing between the basis function centers. Each set is written
to a file in a common directory.
}
\details{
In the Bayesian modeling, the weight applied to the basis function must be
estimated. For this weight to be identifable, there must be enough samples
with large enough function values. The lower threshold for the minimum
number of samples is specified by \code{prune_minNumSamples}; the default value
of 5 seems adequate. The lower threshold for the function value is specified
by \code{prune_minFuncValue}; the default value of 0.1 seems adequate.
If it is necessary to remove centers that are outside the domain, set argument
prune_areOutsideRemoved to TRUE.

For each element of \code{spacings}, an R-language list is constructed that
includes the spacing,
argument \code{CRS_arg_longlat},
argument \code{CRS_arg_utm},
argument \code{seed},
argument \code{prune_minFuncValue},
argument \code{prune_minNumSamples},
argument \code{prune_areOutsideRemoved},
matrix \code{centers_utm},
matrix \code{centers_longlat},
and matrix \code{BasisFuncs}.

\itemize{
\item Matrix \code{centers_utm} contains the utm coordinates
of the (basis function) centers. Each row in the
matrix pertains the center of one basis function. The first column lists
the easting in meters, and the second lists the northing in meters.
The datum for these coordinates is specified in argument \code{CRS_arg_utm}.
The calculation of these centers is partly random; to make it
reproducible, argument \code{seed} must be set to a natural number.

\item Matrix \code{centers_longlat} contains the longitudes and latitudes
of the (basis function) centers. Each row in the
matrix pertains the center of one basis function. The first column lists
the longitudes, and the second lists the latitudes. The datum for these
coordinates is specified in argument \code{CRS_arg_longlat}. These latitudes
and longitudes are calculated from the utm coordinates in matrix
\code{centers_utm}.

\item Matrix \code{BasisFuncs} contains the values of the basis
functions at the sample locations, which are specified in
argument \code{spatialData}.
The basis function itself is the local
bisquare function (Cressie and Johannesson, 2008).
Each column of the matrix pertains to
one basis function. (Thus, the
number of columns in this matrix equals the number of rows in matrix
centers_longlat.) Each row of the matrix comprises the values of the basis
functions at the sample locations. (Thus, the number of rows in this matrix
equals the number of sample locations in \code{spatialData}.) The
matrix is sparse and is stored in the "dictionary-of-keys" format, which is
implemented with class Matrix::dgTMatrix.
}

This list is
written to a file, for which the name includes the spacing between the
basis function centers. This file is placed in
directory \code{directory_name}.
}
\references{
Cressie, N., and Johnnesson, G., 2008, Fixed rank kriging for very large
spatial data sets: Journal of the Royal Statistical Society, Section B,
vol. 70, Part 1, p. 209-226.
}
