% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CheckResiduals.R
\name{CheckResiduals}
\alias{CheckResiduals}
\title{Constructor of class to check the residuals}
\usage{
CheckResiduals(spatialData, rawSamples)
}
\arguments{
\item{spatialData}{Container with the spatial data and associated information.
See the User's Guide for a detailed description of this container.}

\item{rawSamples}{S4 class returned by function rstan::sampling, which contains samples
of the posterior probability density function.}
}
\value{
A list with the following components is returned.

\item{residuals}{R-language tibble that contains
\itemize{
  \item \code{X}, the field samples values
  \item \code{Y_mean}, the process means
  \item \code{Y_sd}, the process standard deviations
  \item \code{tau}, the standard deviations of the predicted measurements
  \item \code{std_residual}, the standardized residuals
  \item \code{relation}, a character vector. If an element is "Greater", then
         the associated standardized residual is greater than 0. If an
         element is "Less", then the associated standardized residual is
         less than or equal to 0.
}
}

\item{call}{Function call.}
}
\description{
This class is used to check the standardized residuals. A residual is defined
as the difference between a field sample value and the expected value
of the associated predicted measurement; the residual is standardized
by dividing it by the standard deviation of the predicted
measurement.
This function calculates these standardized residuals as well as
various related quantities that are needed to perform the
checks; the checks themselves are performed using other functions
that are associated with this class.
}
\details{
The expected value of a predicted measurement is the process mean;
the standard deviation of a predicted measurement is the
square root of its variance, which equals
the process variance plus the variance of the measurement error.
}
