% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CheckTransect.R
\name{CheckTransect}
\alias{CheckTransect}
\title{Constructor of class to check the model along a transect}
\usage{
CheckTransect(spatialData, maxOffset, end_points, CRS_arg_utm)
}
\arguments{
\item{spatialData}{Container with the spatial data and associated information.
See the User's Guide for a detailed description of this container.}

\item{maxOffset}{Real-valued scalar that specifies the maximum offset---namely, the
maximum distance (in kilometers) between a field sample and the transect.
Field
samples for which the offset is less than maxOffset are included in the
transect; otherwise, they are not.}

\item{end_points}{R-language dataframe containing the locations of the two ends of the
transect. Each row pertains one end.
The locations are specified with longitude and latitude; the column headings
in the dataframe are "long" and "lat". The datum for the longitudes and
latitudes must be the same as that used for argument \code{spatialData}.}

\item{CRS_arg_utm}{Character string containing the arguments to function sp::CRS that
specify the projection, in universal transverse mercator (utm) coordinates,
for arguments \code{spatialData} and \code{end_points}.}
}
\value{
A list with the following components is returned.

\item{maxOffset}{Argument \code{maxOffset}.}

\item{end_points}{Argument \code{end_points}.}

\item{CRS_arg_longlat}{Character string containing the arguments to
function sp::CRS that specify the projection for longitudes and latitudes
for arguments \code{spatialData} and \code{end_points.}}

\item{CRS_arg_utm}{Argument \code{CRS_arg_utm}.}

\item{areInTransect}{Logical vector indicating whether the field
samples in \code{spatialData} are included in the transect.}

\item{distanceAlongTransect}{Real-valued vector containing the
distances along the transect of just the field samples that are in the
transect.}

\item{distanceFromTransect}{Real-valued vector containing the
distances from the transect (namely, the offset perpendicular to the
transect) of just the field samples that are in the transect.}

\item{sampleLocations_longlat}{R-language tibble containing the
longitudes and latitudes of just the field samples that are included in
the transect.}

\item{Value}{Real-valued vector containing the measured values of
just the field samples that are in the transect.}

\item{call}{Function call.}
}
\description{
This constructor calculates various quantities are needed to
to check the suitability of the statistical model along transect.
The checks themselves are performed using graphics, which are plotted
by other functions associated with this class.
}
