% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CrossValidation.R
\name{CrossValidation}
\alias{CrossValidation}
\title{Constructor of class to perform cross validation test}
\usage{
CrossValidation(spatialData, BMNUS_sm, oBasisFunctions, nFolds, nCpuCores,
  selected_spacings = NULL, directory_name = paste0("CrossValidation_",
  nFolds, "-Folds"), sub_domain_boundary = NULL)
}
\arguments{
\item{spatialData}{Container with the spatial data and associated information.
See the User's Guide for a detailed description of this container.}

\item{BMNUS_sm}{The compiled stan program BMNUS.}

\item{oBasisFunctions}{Object of class BasisFunctions.}

\item{nFolds}{Number of folds for the cross validation test.}

\item{nCpuCores}{Number of processor (cpu) cores that are used for the parallel calculations.
This parameter should be less than the number of logical cores.}

\item{selected_spacings}{Character vector that contains the spacings for which the cross validation
is performed. That is, sometimes the cross
validation test needs to be perfromed for only some of the spacings that
were previously computed by class \code{BasisFunctions}. If so, these
spacings are specified in this vector.}

\item{directory_name}{Character string containing the name of the directory that will store
the files with the results of the cross validation test.}

\item{sub_domain_boundary}{R-language tibble that contains the longitudes and latitudes of the
points that define the boundary of a sub-domain.
Within the tibble, latitude and longitude are designated "lat" and "long".
This sub-domain must be a subset of the domain.}
}
\value{
A list with the following components is returned.

\item{nFolds}{Argument \code{nFolds}.}

\item{nCpuCores}{Argument \code{nCpuCores}.}

\item{selected_spacings}{Argument \code{selected_spacings}.}

\item{center_spacings}{Spacings between basis function centers,
in kilometers, at which the cross validation test is performed.}

\item{results}{R-language list, for which the number of elements
equals the  number of spacings between basis function centers.
That is, each element of \code{results} is associated with an element of
\code{center_spacings}.}
Each element of \code{results} is a tibble
that contains the two measures of predictive accuracy: the deviance, and
the mean squared error (Gelman and others, 2014, p. 166-178). The number
of rows in the tibble equals the number of folds.

\item{call}{Function call.}
}
\description{
This constructor performs a cross validation test for one or more spacings
between basis function centers. The test may be performed either for
the entire domain or for a sub-domain.
The test is performed using parallel processing to reduce computation time.
}
\details{
The duration of the computations depends upon many factors, including
the number of basis functions, the number of measurements in the domain,
the number of folds, and the speed of the computer. Thus, predicting the
duration is practically impossible. Nonetheless, the duration is much longer
than the other computations in package BMNUS.

Sometimes, it may desirable to perform a cross validation test for a portion
of a domain. For example, if the domain has areas with different sampling
densities, then it may desirable to perform tests for individual areas.
This can be accomplished by using argument \code{sub_domain_boundary}---the
cross validation test is performed only for the samples within the specified
sub-domain.
}
\references{
Gelman, A., Carlin, J.B., Stern, H.S., Dunson, D.B., Vehtari, A., and
Rubin, D.B., 2014, Bayesian data analysis (3d ed.): Boca Raton, Fla.,
CRC Press.
}
