% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Predictions.R
\name{Prediction}
\alias{Prediction}
\title{Constructor of class to predict values throughout the domain.}
\usage{
Prediction(domain_boundary, spatialData, CRS_arg_utm, basis_functions,
  rawSamples, threshold, probability = 0.95, n_pred_pts = 10000L,
  seed = 777, directory_name = "Predictions")
}
\arguments{
\item{domain_boundary}{R-language dataframe containing the longitudes and latitudes of the
points that define the boundary of the domain. The first column
of the dataframe lists the longitudes, and the second column
the latitudes. The column names are "long" and "lat".}

\item{spatialData}{Container with the spatial data and associated information.
See the User's Guide for a detailed description of this container.}

\item{CRS_arg_utm}{Character string containing the arguments to function sp::CRS that
specify the projection, in universal transverse mercator (utm) coordinates,
for arguments domain_boundary.}

\item{basis_functions}{R-language list containing the basis functions at the selected spacing
between function centers. This list is completely described in the
documentation for function BasisFunctions.}

\item{rawSamples}{S4 class returned by function rstan::sampling, which contains samples
of the posterior probability density function.}

\item{threshold}{Real-valued scalar. The probability of exceeding this threshold is calculated
at all prediction locations. If the original data are concentrations, then this
threshold must be transformed with the isometric log-ratio transform before
it is passed to this function.}

\item{probability}{Real-valued scalar between 0 and 1. The quantile at this probability is
calculated at all prediction locations.}

\item{n_pred_pts}{Number of prediction locations}

\item{seed}{Random number seed. Calculating the locations at which the values
are predicted is partly random, so setting this seed makes the calculations
reproducible.}

\item{directory_name}{Character string containing the name of the directory that will store
the files with the predictions.}
}
\value{
A list with the following components is returned.

\item{domain_boundary}{Argument \code{domain_boundary}.}

\item{CRS_arg_longlat}{Argument \code{CRS_arg_longlat}.}

\item{CRS_arg_utm}{Argument \code{CRS_arg_utm}.}

\item{threshold}{Argument \code{threshold}.}

\item{probability}{Argument \code{probability}.}

\item{n_pred_pts}{Argument \code{n_pred_pts}.}

\item{seed}{Argument \code{seed}.}

\item{directory_name}{Argument \code{directory_name}.}

\item{predictedValues}{R-language tibble containing, at each
prediction location,
\itemize{
  \item \code{long}, the longitude
  \item \code{lat}, the latitude
  \item \code{easting}, the utm easting
  \item \code{northing}, the utm northing
  \item \code{Y_mean}, the process mean
  \item \code{Y_sd}, the process standard deviation
  \item \code{prob}, the probability of exceeding argument \code{threshold}
  \item \code{quantile}, the quantile associated with
         argument \code{probability}
}
The datum for the longitudes and latitudes
is specifed in argument \code{CRS_arg_longlat}. The datum for the easthings
and northings is is specifed in argument \code{CRS_arg_utm}.}

\item{call}{Function call.}
}
\description{
This constructor calculates the locations in the domain
at which various values
are predicted and then predicts the values at those locations. The predicted
values
are the process mean, the process standard deviation,
the probability of exceeding a specified threshold, and
the quantile associated with a specifed probability.
}
\details{
The prediction locations are stored in file \code{Pred_points.dat} in
directory \code{directory_name}. The predicted values likewise are stored in
file \code{PredictedValues.dat} in directory \code{directory_name}.
}
