% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SimpleCrossValidation.R
\name{SimpleCrossValidation}
\alias{SimpleCrossValidation}
\title{Constructor of class to perform simple cross validation test}
\usage{
SimpleCrossValidation(training_spatialData, validation_spatialData,
  BMNUS_sm, oBasisFunctions, nCpuCores)
}
\arguments{
\item{training_spatialData}{Container with the training measurements, which are a type of spatial data.
These data are used to training the statistical model, namely estimate the
parameters in the model.
See the User's Guide for a detailed description of this container.}

\item{validation_spatialData}{Container with the validation measurements, which also are a type of spatial
data. These
data are used to test how well the statistical model can predict values
of the physical property that is being modeled.
See the User's Guide for a detailed description of this container.}

\item{BMNUS_sm}{The compiled stan program BMNUS.}

\item{oBasisFunctions}{Object of class BasisFunctions.}

\item{nCpuCores}{Number of processor (cpu) cores that are used for the parallel calculations.
This parameter should be less than the number of logical cores.}
}
\value{
A list with the following components is returned.

\item{nCpuCores}{Argument \code{nCpuCores}.}

\item{results}{R-language tibble, for which the number of rows
equals the  number of spacings between basis function centers. The
first column lists the spacings, in kilometers, between basis function
centers. The second column lists the deviances, and the third column lists
the mean squared errors. The deviance and mean squared error
are measures of predictive accuracy in the cross validation test
(Gelman and others, 2014, p. 166-178).}

\item{call}{Function call.}
}
\description{
This constructor performs a simple cross validation test for one or more
spacings
between basis function centers. The qualifier "simple" means that
validation data is available and is used for the cross validation.
The test is performed using parallel processing to reduce computation time.
}
\details{
The duration of the computations depends upon many factors, including
the number of basis functions, the number of training measurements,
the number of validation measurements,
and the speed of the computer. Thus, predicting the
duration is practically impossible.
}
\references{
Gelman, A., Carlin, J.B., Stern, H.S., Dunson, D.B., Vehtari, A., and
Rubin, D.B., 2014, Bayesian data analysis (3d ed.): Boca Raton, Fla.,
CRC Press.
}
