% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GeneralUtilities.R
\name{SparseCarQuantities}
\alias{SparseCarQuantities}
\title{Calculate quantities needed for the sparse CAR model}
\usage{
SparseCarQuantities(basis_functions, tol = 1e-06)
}
\arguments{
\item{basis_functions}{R-language list that is generated by class BasisFunctions. This list is
described in the documentation for function \code{BasisFunctions}.}

\item{tol}{Positive real number. See details.}
}
\value{
If the adjacency matrix has one or more rows that are comprised
of just zeros, then the indices of those rows are returned as an
integer-valued vector. Otherwise, a list with the following components
is returned.

\item{nNeighborPairs}{Integer-valued scalar. Number of neighbor
pairs in the adjacency matrix.}

\item{W_sparse}{Integer-valued matrix. The first column lists the row
indices of the non-zero elements in the upper triangle of the adjacency
matrix. Only the upper triangle is used because the adjacency matrix is
symmetric. The second column lists the associated column indices of the
adjacency matrix.}

\item{D_sparse}{Real-valued vector. This vector is the diagonal of
diagonal matrix D that is used in sparse CAR formulation. See the
reference.}

\item{lambda}{Real-valued vector. This vector comprises the
eigenvalues of matrix D^(-1/2) W D^(-1/2) that is used in sparse CAR
formulation. See the reference.}
}
\description{
The sparse CAR model, which was developed by M. Joseph, does not
directly require the adjacency matrix. Rather, it requires a scalar,
two vectors, and a matrix that are derived from the adjacency matrix.
These quantities are calculated before calling stan program BMNUS, so
that the quantities are not calculated for each chain, which would be
repetitous. These quantities are calculated in this function.
}
\details{
Calculating the adjacency matrix involves determining the neighbors of every
basis function center. This determination is based on the distance between
the neighbors and
is controlled by argument \code{tol}. That is, if a (normalized) distance
is between \code{1 - tol} and \code{1 + tol}, then the associated center is
deemed a neighbor. Otherwise, it is not.
}
\references{
Joseph, Max, Exact sparse CAR models in Stan, Internet web page available at
http://mc-stan.org/documentation/case-studies/mbjoseph-CARStan.html,
last accessed September 2019.
}
