% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GisUtilities.R
\name{read_point_shapefile}
\alias{read_point_shapefile}
\title{Read a point shapefile}
\usage{
read_point_shapefile(directory, shapefile_name, isConcentration = FALSE,
  constSumValue = 1e+06)
}
\arguments{
\item{directory}{Name of the directory containing the shapefiles}

\item{shapefile_name}{Name of the shapefile to be read.}

\item{isConcentration}{Logical indicator specifying whether the measurements are concentrations.}

\item{constSumValue}{If the measurements are concentrations (argument \code{isConcentration}),
this argument is a real, positive-value scalar specifying the constant sum
value for those concentrations,}
}
\value{
A R-language SpatialPointsDataFrame that contains the spatial
data. This container is defined in the sp package. The
SpatialPointsDataFrame contains the measurements in column \code{Value}
and the
censor indicators in column \code{IndicatorValue}. If the measurements
are concentrations, then the data in colum \code{Value} are the
isometric log-ratio transform of the concentrations. Also, the original
measurements (concentrations) are in column \code{OriginalValue}.
}
\description{
Read a point shapefile of data for statistical modeling.
}
\details{
The shapefile must include at least the following:
\itemize{
  \item Measurements of the physical property that are to be modeled. The
  attribute name is \code{Value}.
  \item Indicators specifying whether measurements are censored. The
  attribute name is \code{IndicatorValue}.
}
An indictor is a character string: "left", "right", or "no".
String "left" means that the associated measurement is left censored;
string "right" means that the associated measurement is right censored;
string "no" means that the associated measurement is not censored.
If a measurement is left censored,
then the associated measurement value is the left censoring threshold.
Likewise, if a measurement is right censored,
the the associated measurement value is the right censoring threshold.
The data may have multiple, different censoring thresholds.

If the measurements are concentrations, then they undergo the isometric
log-ratio transformation (Pawlowsky-Glahn and others, 2015). This
transformation requires a parameter called the constant sum value, which
is specified in argument \code{constSumValue}.
This argument is most easily explained with examples.
If the concentrations are reported in percent,
then argument \code{constSumValue} is 100; if they are reported in
milligrams per kilogram (or equivalently parts per million), then
argument \code{constSumValue} is 1000000; and if they are reported in
parts per billion, then argument \code{constSumValue} is 1000000000.
}
\references{
Pawlowsky-Glahn, V., Egozcue, J.J., and Tolosana-Delgado, R., 2015, Modeling
and analysis of compositional data: John Wiley and Sons, Ltd.
}
